@@ -25,7 +25,7 @@ from .version import __version__
 __all__ = ('diff', 'patch', 'swap', 'revert', 'dot_lookup', '__version__')
 
 
-def diff(first, second, node=None):
+def diff(first, second, node=None, ignore=None):
     """Compare two dictionary object, and returns a diff result.
 
     Return iterator with differences between two dictionaries.
@@ -34,6 +34,13 @@ def diff(first, second, node=None):
         >>> list(result)
         [('change', 'a', ('b', 'c'))]
 
+    :param first: original dictionary or list
+    :param second: new dictionary or list
+    :param node: key for comparison that can be used in :func:`dot_lookup`
+    :param ignore: list of keys that should not be checked
+
+    .. versionchanged:: 0.3
+       Added *ignore* parameter.
     """
     node = node or []
     if all(map(lambda x: isinstance(x, string_types), node)):
@@ -41,11 +48,22 @@ def diff(first, second, node=None):
     else:
         dotted_node = list(node)
 
+    differ = False
+
     if isinstance(first, dict) and isinstance(second, dict):
         # dictionaries are not hashable, we can't use sets
-        intersection = [k for k in first if k in second]
-        addition = [k for k in second if k not in first]
-        deletion = [k for k in first if k not in second]
+        def check(key):
+            """Test if key in current node should be ignored."""
+            return ignore is None \
+                or (dotted_node + [key] if isinstance(dotted_node, list)
+                    else '.'.join(node + [str(key)])) not in ignore
+
+        intersection = [k for k in first if k in second and check(k)]
+        addition = [k for k in second if k not in first and check(k)]
+        deletion = [k for k in first if k not in second and check(k)]
+
+        differ = True
+
     elif isinstance(first, list) and isinstance(second, list):
         len_first = len(first)
         len_second = len(second)
@@ -54,23 +72,21 @@ def diff(first, second, node=None):
         addition = list(range(min(len_first, len_second), len_second))
         deletion = list(reversed(range(min(len_first, len_second), len_first)))
 
-    def diff_dict_list():
-        """Compare if object is a dictionary.
+        differ = True
 
-        Call again the parent function as recursive if dictionary have child
-        objects.  Yields `add` and `remove` flags.
-        """
+    if differ:
+        # Compare if object is a dictionary.
+        #
+        # Call again the parent function as recursive if dictionary have child
+        # objects.  Yields `add` and `remove` flags.
         for key in intersection:
             # if type is not changed, callees again diff function to compare.
             # otherwise, the change will be handled as `change` flag.
-            node_key = str(key) if all(
-                [isinstance(key, int), isinstance(first[key], list),
-                 isinstance(second[key], list)]
-            ) else key
             recurred = diff(
                 first[key],
                 second[key],
-                node=node + [node_key])
+                node=node + [key],
+                ignore=ignore)
 
             for diffed in recurred:
                 yield diffed
@@ -87,19 +103,11 @@ def diff(first, second, node=None):
                 # and values.
                 (key, first[key]) for key in deletion]
 
-    def diff_otherwise():
-        """Compare string and integer types and yield `change` flag."""
+    else:
+        # Compare string and integer types and yield `change` flag.
         if first != second:
             yield CHANGE, dotted_node, (first, second)
 
-    differs = {
-        dict: diff_dict_list,
-        list: diff_dict_list,
-    }
-
-    differ = differs.get(type(first))
-    return ((isinstance(second, type(first)) and differ) or diff_otherwise)()
-
 
 def patch(diff_result, destination):
     """Patch the diff result to the old dictionary."""
